@@ -3,5 +3,5 @@ from .Friends import Friends
 from .Games import Games
 from .Inventory import Inventory
 from .Users import Users
-from .Errors import Errors
+from .Errors import Exceptions
 from .Groups import Groups
\ No newline at end of file
